==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/MeshPart/Gui/Resources/translations/MeshPart_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr" sourcelanguage="en">
  <context>
    <name>CmdMeshPartCurveOnMesh</name>
    <message>
      <location filename="../../Command.cpp" line="+245"/>
      <source>Mesh</source>
      <translation>Parçacık</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh...</source>
      <translation>Örgü eğrisi...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh</source>
      <translation>Örgü eğrisi</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartMesher</name>
    <message>
      <location line="-191"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create mesh from shape...</source>
      <translation>Parçacıktan şekil oluştur</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Tessellate shape</source>
      <translation>Şekili mozaik döşe</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartSection</name>
    <message>
      <location line="+106"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create section from mesh and plane</source>
      <translation>Örgü ve düzlemden kesit oluştur</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Section</source>
      <translation>Bölüm</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartTrimByPlane</name>
    <message>
      <location line="-85"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Trim mesh with a plane</source>
      <translation>Bir düzlem ile örgü bölme</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Trims a mesh with a plane</source>
      <translation>Bir düzlemle örgü kesme</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CurveOnMeshHandler</name>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="+353"/>
      <source>Create</source>
      <translation>Oluştur</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Close wire</source>
      <translation>Telin Yakını</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Clear</source>
      <translation>Temizle</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Cancel</source>
      <translation>İptal et</translation>
    </message>
    <message>
      <location line="+208"/>
      <source>Wrong mesh picked</source>
      <translation>Yanlış örgü seçildi</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>No point was picked</source>
      <translation>Hiçbir nokta seçilmedi</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::TaskCurveOnMesh</name>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="+14"/>
      <source>Curve on mesh</source>
      <translation>Örgü eğrisi</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Wire</source>
      <translation>Yay</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Snap tolerance to vertexes</source>
      <translation>Noktalara yapışma toleransı</translation>
    </message>
    <message>
      <location line="+7"/>
      <source> px</source>
      <translation> piksel</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Split threshold</source>
      <translation>Bölme eşiği</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Spline Approximation</source>
      <translation>Spline Yaklaşımı</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Tolerance to mesh</source>
      <translation>Örgü toleransı</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Continuity</source>
      <translation>Süreklilik</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Maximum curve degree</source>
      <translation>Maksimum eğri derecesi</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>Start</source>
      <translation>Başla</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::Tessellation</name>
    <message>
      <location filename="../../Tessellation.ui" line="+14"/>
      <source>Tessellation</source>
      <translation>Mozaikleme</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Shapes</source>
      <translation>Şekiller</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Meshing options</source>
      <translation>Örgü seçenekleri</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Standard</source>
      <translation>Standart</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Mefisto</source>
      <translation>Mefisto</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Netgen</source>
      <translation>Netgen</translation>
    </message>
    <message>
      <location line="+81"/>
      <source>Define segments by face colors</source>
      <translation>Kesimleri yüz renkleriyle tanımlama</translation>
    </message>
    <message>
      <location line="-7"/>
      <source>Apply face colors to mesh</source>
      <translation>Örgü için yüz renkleri uygula</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>Angular deviation:</source>
      <translation>Açısal sapma:</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Relative surface deviation</source>
      <translation>Göreceli yüzey sapması</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>Maximum edge length:</source>
      <translation>En fazla kenar uzunluğu:</translation>
    </message>
    <message>
      <location line="+44"/>
      <source>Fineness:</source>
      <translation>İnceliği:</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>Very coarse</source>
      <translation>Çok kaba</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Coarse</source>
      <translation>Kaba</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Moderate</source>
      <translation>Normal</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Fine</source>
      <translation>İyi</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Very fine</source>
      <translation>Çok iyi</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>User defined</source>
      <translation>Kullanıcı tanımlı</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Mesh size grading:</source>
      <translation>Mesh ebadı derecelendirmesi:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per edge:</source>
      <translation>Kenar başına öğeler:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per curvature radius:</source>
      <translation>Eğrilik yarıçapındaki elemanlar:</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>Optimize surface</source>
      <translation>Yüzeyi en iyileştir</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Second order elements</source>
      <translation>İkinci mertebeden elemanlar</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Quad dominated</source>
      <translation>Dörtlü hakimdi</translation>
    </message>
    <message>
      <source>Settings</source>
      <translation>Ayarlar</translation>
    </message>
    <message>
      <location line="-293"/>
      <source>Surface deviation:</source>
      <translation>Yüzey sapması:</translation>
    </message>
    <message>
      <source>Max. edge length:</source>
      <translation>Kenar uzunluğunun en büyük değeri:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="+225"/>
      <source>Select a shape for meshing, first.</source>
      <translation>Önce parçacık haline getirmek için bir şekil seçiniz.</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>No such document '%1'.</source>
      <translation>'%1' adlı belge bulunamadı.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_Section</name>
    <message>
      <location filename="../../Command.cpp" line="+93"/>
      <source>Select plane</source>
      <translation>Uçak seç</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you section the mesh.</source>
      <translation>Lütfen kafesin kesildiği bir düzlem seçin.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_TrimByPlane</name>
    <message>
      <location line="-85"/>
      <source>Select plane</source>
      <translation>Uçak seç</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you trim the mesh.</source>
      <translation>Lütfen örgünün düzeltileceği bir düzlem seçin.</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>MeshPart</source>
      <translation>ParçacıkBölümü</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/MeshPart/Gui/Resources/translations/MeshPart_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr" sourcelanguage="en">
  <context>
    <name>CmdMeshPartCurveOnMesh</name>
    <message>
      <location filename="../../Command.cpp" line="+290"/>
      <source>Mesh</source>
      <translation>Parçacık</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh...</source>
      <translation>Örgü eğrisi...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Curve on mesh</source>
      <translation>Örgü eğrisi</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartMesher</name>
    <message>
      <location line="-235"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create mesh from shape...</source>
      <translation>Parçacıktan şekil oluştur</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Tessellate shape</source>
      <translation>Şekili mozaik döşe</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartSection</name>
    <message>
      <location line="+150"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create section from mesh and plane</source>
      <translation>Örgü ve düzlemden kesit oluştur</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Section</source>
      <translation>Bölüm</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartTrimByPlane</name>
    <message>
      <location line="-129"/>
      <source>Mesh</source>
      <translation type="unfinished">Mesh</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Trim mesh with a plane</source>
      <translation>Bir düzlem ile örgü bölme</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <source>Trims a mesh with a plane</source>
      <translation>Bir düzlemle örgü kesme</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CurveOnMeshHandler</name>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="+353"/>
      <source>Create</source>
      <translation>Oluştur</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Close wire</source>
      <translation>Telin Yakını</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Clear</source>
      <translation>Temizle</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Cancel</source>
      <translation>İptal et</translation>
    </message>
    <message>
      <location line="+208"/>
      <source>Wrong mesh picked</source>
      <translation>Yanlış örgü seçildi</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>No point was picked</source>
      <translation>Hiçbir nokta seçilmedi</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::TaskCurveOnMesh</name>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="+14"/>
      <source>Curve on mesh</source>
      <translation>Örgü eğrisi</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Wire</source>
      <translation>Yay</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Snap tolerance to vertexes</source>
      <translation>Köşelere yapışma toleransı</translation>
    </message>
    <message>
      <location line="+7"/>
      <source> px</source>
      <translation> piksel</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Split threshold</source>
      <translation>Bölme eşiği</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Spline Approximation</source>
      <translation>Spline Yaklaşımı</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Tolerance to mesh</source>
      <translation>Örgü toleransı</translation>
    </message>
    <message>
      <location line="+26"/>
      <source>Continuity</source>
      <translation>Süreklilik</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Maximum curve degree</source>
      <translation>Maksimum eğri derecesi</translation>
    </message>
    <message>
      <location line="+24"/>
      <source>Start</source>
      <translation>Başla</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::Tessellation</name>
    <message>
      <location filename="../../Tessellation.ui" line="+14"/>
      <source>Tessellation</source>
      <translation>Mozaikleme</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Shapes</source>
      <translation>Şekiller</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Meshing options</source>
      <translation>Örgü seçenekleri</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Standard</source>
      <translation>Standart</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Mefisto</source>
      <translation>Mefisto</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Netgen</source>
      <translation>Netgen</translation>
    </message>
    <message>
      <location line="+81"/>
      <source>Define segments by face colors</source>
      <translation>Kesimleri yüz renkleriyle tanımlama</translation>
    </message>
    <message>
      <location line="-7"/>
      <source>Apply face colors to mesh</source>
      <translation>Örgü için yüz renkleri uygula</translation>
    </message>
    <message>
      <location line="-35"/>
      <source>Angular deviation:</source>
      <translation>Açısal sapma:</translation>
    </message>
    <message>
      <location line="+28"/>
      <source>Relative surface deviation</source>
      <translation>Göreceli yüzey sapması</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>Maximum edge length:</source>
      <translation>En fazla kenar uzunluğu:</translation>
    </message>
    <message>
      <location line="+44"/>
      <source>Fineness:</source>
      <translation>İnceliği:</translation>
    </message>
    <message>
      <location line="+17"/>
      <source>Very coarse</source>
      <translation>Çok kaba</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Coarse</source>
      <translation>Kaba</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Moderate</source>
      <translation>Normal</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Fine</source>
      <translation>İyi</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>Very fine</source>
      <translation>Çok iyi</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>User defined</source>
      <translation>Kullanıcı tanımlı</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Mesh size grading:</source>
      <translation>Mesh ebadı derecelendirmesi:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per edge:</source>
      <translation>Kenar başına öğeler:</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Elements per curvature radius:</source>
      <translation>Eğrilik yarıçapındaki elemanlar:</translation>
    </message>
    <message>
      <location line="+31"/>
      <source>Optimize surface</source>
      <translation>Yüzeyi en iyileştir</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>Second order elements</source>
      <translation>İkinci mertebeden elemanlar</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>Quad dominated</source>
      <translation>Dörtlü hakimdi</translation>
    </message>
    <message>
      <source>Settings</source>
      <translation>Ayarlar</translation>
    </message>
    <message>
      <location line="-293"/>
      <source>Surface deviation:</source>
      <translation>Yüzey sapması:</translation>
    </message>
    <message>
      <source>Max. edge length:</source>
      <translation>Kenar uzunluğunun en büyük değeri:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="+226"/>
      <source>Select a shape for meshing, first.</source>
      <translation>Önce parçacık haline getirmek için bir şekil seçiniz.</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>No such document '%1'.</source>
      <translation>'%1' adlı belge bulunamadı.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_Section</name>
    <message>
      <location filename="../../Command.cpp" line="+137"/>
      <source>Select plane</source>
      <translation>Uçak seç</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you section the mesh.</source>
      <translation>Lütfen kafesin kesildiği bir düzlem seçin.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_TrimByPlane</name>
    <message>
      <location line="-129"/>
      <source>Select plane</source>
      <translation>Uçak seç</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Please select a plane at which you trim the mesh.</source>
      <translation>Lütfen örgünün düzeltileceği bir düzlem seçin.</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Trim by plane</source>
      <translation>Düzlemden Kırp</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Select the side you want to keep.</source>
      <translation>Tutmak istediğin kenarı seç.</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Inner</source>
      <translation>İç</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Outer</source>
      <translation>Dış</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Split</source>
      <translation>Ayır</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>MeshPart</source>
      <translation>ParçacıkBölümü</translation>
    </message>
  </context>
</TS>
